/*
 * Copyright 2009 SpringSource
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.bundlor.maven.plugin.internal.support;

import java.io.File;
import java.io.StringReader;
import java.util.Map;

import org.springframework.util.StringUtils;

import com.springsource.bundlor.maven.plugin.internal.ManifestTemplateFactory;
import com.springsource.bundlor.util.BundleManifestUtils;
import com.springsource.bundlor.util.SimpleManifestContents;
import com.springsource.util.parser.manifest.ManifestContents;

public final class StandardManifestTemplateFactory implements ManifestTemplateFactory {

    private static final String BUNDLE_SYMBOLIC_NAME = "Bundle-SymbolicName";

    private static final String BUNDLE_VERSION = "Bundle-Version";

    public ManifestContents create(String manifestTemplatePath, String manifestTemplate, String bundleSymbolicName, String defaultBundleSymbolicName,
        String bundleVersion, String defaultBundleVersion) {
        ManifestContents template;
        if (StringUtils.hasText(manifestTemplate)) {
            template = BundleManifestUtils.getManifest(new StringReader(manifestTemplate));
        } else if (StringUtils.hasText(manifestTemplatePath)) {
            template = BundleManifestUtils.getManifest(new File(manifestTemplatePath));
        } else {
            template = new SimpleManifestContents();
        }

        Map<String, String> attributes = template.getMainAttributes();
        if (StringUtils.hasText(bundleSymbolicName)) {
            attributes.put(BUNDLE_SYMBOLIC_NAME, bundleSymbolicName);
        } else if (!StringUtils.hasText(attributes.get(BUNDLE_SYMBOLIC_NAME))) {
            attributes.put(BUNDLE_SYMBOLIC_NAME, defaultBundleSymbolicName);
        }
                
        if (StringUtils.hasText(bundleVersion)) {
            attributes.put(BUNDLE_VERSION, bundleVersion);
        } else if (!StringUtils.hasText(attributes.get(BUNDLE_VERSION))) {
            attributes.put(BUNDLE_VERSION, defaultBundleVersion);
        }

        return template;
    }

}
